==> haskell-shellmet-0.0.5.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-KlYYJHXo3uFChjKz85iGhu
key:                  shellmet-0.0.5.0-KlYYJHXo3uFChjKz85iGhu
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  4969238b545db722dcf4200d8afc50bf
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-KlYYJHXo3uFChjKz85iGhu
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shellmet-0.0.5.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-BgbMFk27vne64zE4WIJlfw
key:                  shellmet-0.0.5.0-BgbMFk27vne64zE4WIJlfw
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  207d144be33e02d398b4fcb3673c6da5
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-BgbMFk27vne64zE4WIJlfw
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
